package models

type Manufacturer struct {
	ID               int64  `gorm:"column:id" json:"id"`
	ManufacturerName string `gorm:"column:manufacturer_name" json:"manufacturer_name"`
	Contact          string `gorm:"column:contact" json:"contact"`
	ContactPhone     string `gorm:"column:contact_phone" json:"contact_phone"`
	PlatformNumber   string `gorm:"column:platform_number" json:"platform_number"`
	Email            string `gorm:"column:email" json:"email"`
	ContactAddress   string `gorm:"column:contact_address" json:"contact_address"`
	Remark           string `gorm:"column:remark" json:"remark"`
	Creater          int64  `gorm:"column:creater" json:"creater"`
	Modifier         int64  `gorm:"column:modifier" json:"modifier"`
	Ctime            int64  `gorm:"column:ctime" json:"ctime"`
	Mtime            int64  `gorm:"column:mtime" json:"mtime"`
	OrgId            int64  `gorm:"column:org_id" json:"org_id"`
	Status           int64  `gorm:"column:status" json:"status"`
	ManufacturerCode string `gorm:"column:manufacturer_code" json:"manufacturer_code"`
	PinYin           string `gorm:"column:pinyin" json:"pinyin"`
	WuBi             string `gorm:"column:wubi" json:"wubi"`
}

func (Manufacturer) TableName() string {
	return "xt_manufacturer"
}

type Dealer struct {
	ID             int64  `gorm:"column:id" json:"id"`
	DealerName     string `gorm:"column:dealer_name" json:"dealer_name"`
	Contact        string `gorm:"column:contact" json:"contact"`
	ContactPhone   string `gorm:"column:contact_phone" json:"contact_phone"`
	PlatformNumber string `gorm:"column:platform_number" json:"platform_number"`
	Email          string `gorm:"column:email" json:"email"`
	ContactAddress string `gorm:"column:contact_address" json:"contact_address"`
	Remark         string `gorm:"column:remark" json:"remark"`
	Creater        int64  `gorm:"column:creater" json:"creater"`
	Modifier       int64  `gorm:"column:modifier" json:"modifier"`
	Ctime          int64  `gorm:"column:ctime" json:"ctime"`
	Mtime          int64  `gorm:"column:mtime" json:"mtime"`
	OrgId          int64  `gorm:"column:org_id" json:"org_id"`
	Status         int64  `gorm:"column:status" json:"status"`
	DealerCode     string `gorm:"column:dealer_code" json:"dealer_code"`
	PinYin         string `gorm:"column:pinyin" json:"pinyin"`
	WuBi           string `gorm:"column:wubi" json:"wubi"`
}

func (Dealer) TableName() string {
	return "xt_dealer"
}

type Warehousing struct {
	ID               int64        `gorm:"column:id" json:"id"`
	WarehousingOrder string       `gorm:"column:warehousing_order" json:"warehousing_order"`
	OperationTime    int64        `gorm:"column:operation_time" json:"operation_time"`
	OrgId            int64        `gorm:"column:org_id" json:"org_id"`
	Creater          int64        `gorm:"column:creater" json:"creater"`
	Ctime            int64        `gorm:"column:ctime" json:"ctime"`
	Modifier         int64        `gorm:"column:modifier" json:"modifier"`
	Mtime            int64        `gorm:"column:mtime" json:"mtime"`
	Status           int64        `gorm:"column:status" json:"status"`
	WarehousingTime  int64        `gorm:"column:warehousing_time" json:"warehousing_time"`
	Dealer           int64        `gorm:"column:dealer" json:"dealer"`
	Manufacturer     int64        `gorm:"column:manufacturer" json:"manufacturer"`
	Manufacturers    Manufacturer `gorm:"ForeignKey:ID;AssociationForeignKey:Manufacturer" json:"Manufacturer"`
	Dealers          Dealer       `gorm:"ForeignKey:ID;AssociationForeignKey:Dealer" json:"Dealer"`
	Type             int64        `gorm:"column:type" json:"type"`
}

func (Warehousing) TableName() string {
	return "xt_warehouse"
}

type StWarehousingInfo struct {
	ID                int64   `gorm:"column:id" json:"id"`
	WarehousingId     int64   `gorm:"column:warehousing_id" json:"warehousing_id"`
	GoodId            int64   `gorm:"column:good_id" json:"good_id"`
	GoodTypeId        int64   `gorm:"column:good_type_id" json:"good_type_id"`
	Number            string  `gorm:"column:number" json:"number"`
	ProductDate       int64   `gorm:"column:product_date" json:"product_date"`
	ExpiryDate        int64   `gorm:"column:expiry_date" json:"expiry_date"`
	WarehousingCount  int64   `gorm:"column:warehousing_count" json:"warehousing_count"`
	WarehousingUnit   string  `gorm:"column:warehousing_unit" json:"warehousing_unit"`
	Price             float64 `gorm:"column:price" json:"price"`
	TotalPrice        float64 `gorm:"column:total_price" json:"total_price"`
	Dealer            int64   `gorm:"column:dealer" json:"dealer"`
	Manufacturer      int64   `gorm:"column:manufacturer" json:"manufacturer"`
	Remark            string  `gorm:"column:remark" json:"remark"`
	Ctime             int64   `gorm:"column:ctime" json:"ctime"`
	Mtime             int64   `gorm:"column:mtime" json:"mtime"`
	Status            int64   `gorm:"column:status" json:"status"`
	OrgId             int64   `gorm:"column:org_id" json:"org_id"`
	IsReturn          int64   `gorm:"column:is_return" json:"is_return"`
	StockCount        int64   `gorm:"column:stock_count" json:"stock_count" form:"stock_count"`
	WarehousingOrder  string  `gorm:"column:warehousing_order" json:"warehousing_order"`
	Type              int64   `gorm:"column:type" json:"type"`
	GoodName          string  `json:"good_name"`
	PackingUnit       string  `json:"packing_unit"`
	TotalCount        int64   `json:"total_count"`
	SpecificationName string  `json:"specification_name"`
	LicenseNumber     string  `gorm:"column:license_number" json:"license_number" form:"license_number"`
}

func (StWarehousingInfo) TableName() string {
	return "xt_warehouse_info"
}

type WarehousingInfo struct {
	ID               int64       `gorm:"column:id" json:"id"`
	WarehousingId    int64       `gorm:"column:warehousing_id" json:"warehousing_id"`
	GoodId           int64       `gorm:"column:good_id" json:"good_id"`
	GoodTypeId       int64       `gorm:"column:good_type_id" json:"good_type_id"`
	Number           string      `gorm:"column:number" json:"number"`
	ProductDate      int64       `gorm:"column:product_date" json:"product_date"`
	ExpiryDate       int64       `gorm:"column:expiry_date" json:"expiry_date"`
	WarehousingCount int64       `gorm:"column:warehousing_count" json:"warehousing_count"`
	WarehousingUnit  string      `gorm:"column:warehousing_unit" json:"warehousing_unit"`
	Price            float64     `gorm:"column:price" json:"price"`
	TotalPrice       float64     `gorm:"column:total_price" json:"total_price"`
	Dealer           int64       `gorm:"column:dealer" json:"dealer"`
	Manufacturer     int64       `gorm:"column:manufacturer" json:"manufacturer"`
	Remark           string      `gorm:"column:remark" json:"remark"`
	Ctime            int64       `gorm:"column:ctime" json:"ctime"`
	Mtime            int64       `gorm:"column:mtime" json:"mtime"`
	Status           int64       `gorm:"column:status" json:"status"`
	OrgId            int64       `gorm:"column:org_id" json:"org_id"`
	IsReturn         int64       `gorm:"column:is_return" json:"is_return"`
	StockCount       int64       `gorm:"column:stock_count" json:"stock_count" form:"stock_count"`
	Warehousing      Warehousing `ForeignKey:WarehousingId json:"warehouse"`
	WarehousingOrder string      `gorm:"column:warehousing_order" json:"warehousing_order"`
	GoodInfo         GoodInfo    `gorm:"ForeignKey:ID;AssociationForeignKey:GoodId" `
	Type             int64       `gorm:"column:type" json:"type"`
	LicenseNumber    string      `gorm:"column:license_number" json:"license_number" form:"license_number"`
}

func (WarehousingInfo) TableName() string {
	return "xt_warehouse_info"
}

type VmWarehousingInfo struct {
	ID                int64       `gorm:"column:id" json:"id"`
	WarehousingId     int64       `gorm:"column:warehousing_id" json:"warehousing_id"`
	GoodId            int64       `gorm:"column:good_id" json:"good_id"`
	GoodTypeId        int64       `gorm:"column:good_type_id" json:"good_type_id"`
	Number            string      `gorm:"column:number" json:"number"`
	ProductDate       int64       `gorm:"column:product_date" json:"product_date"`
	ExpiryDate        int64       `gorm:"column:expiry_date" json:"expiry_date"`
	WarehousingCount  int64       `gorm:"column:warehousing_count" json:"warehousing_count"`
	WarehousingUnit   string      `gorm:"column:warehousing_unit" json:"warehousing_unit"`
	Price             float64     `gorm:"column:price" json:"price"`
	BuyPrice          float64     `gorm:"column:buy_price" json:"buy_price" form:"buy_price"`
	TotalPrice        float64     `gorm:"column:total_price" json:"total_price"`
	Dealer            int64       `gorm:"column:dealer" json:"dealer"`
	Manufacturer      int64       `gorm:"column:manufacturer" json:"manufacturer"`
	Remark            string      `gorm:"column:remark" json:"remark"`
	Ctime             int64       `gorm:"column:ctime" json:"ctime"`
	Mtime             int64       `gorm:"column:mtime" json:"mtime"`
	Status            int64       `gorm:"column:status" json:"status"`
	OrgId             int64       `gorm:"column:org_id" json:"org_id"`
	IsReturn          int64       `gorm:"column:is_return" json:"is_return"`
	StockCount        int64       `gorm:"column:stock_count" json:"stock_count" form:"stock_count"`
	Warehousing       Warehousing `ForeignKey:WarehousingId json:"warehouse"`
	WarehousingOrder  string      `gorm:"column:warehousing_order" json:"warehousing_order"`
	GoodInfo          GoodInfo    `gorm:"ForeignKey:ID;AssociationForeignKey:GoodId" `
	Type              int64       `gorm:"column:type" json:"type"`
	GoodName          string      `gorm:"column:good_name" json:"good_name"`
	SpecificationName string      `gorm:"column:specification_name" json:"specification_name" form:"specification_name"`
	MinNumber         int64       `gorm:"column:min_number" json:"min_number" form:"min_number"`
	PackingUnit       string      `gorm:"column:packing_unit" json:"packing_unit" form:"packing_unit"`
	Count             int64       `gorm:json:"count"`
}

type WarehouseOut struct {
	ID                      int64        `gorm:"column:id" json:"id"`
	WarehouseOutOrderNumber string       `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number"`
	OperationTime           int64        `gorm:"column:operation_time" json:"operation_time"`
	Creater                 int64        `gorm:"column:creater" json:"creater"`
	OrgId                   int64        `gorm:"column:org_id" json:"org_id"`
	Modifier                int64        `gorm:"column:modifier" json:"modifier"`
	Remark                  string       `gorm:"column:remark" json:"remark"`
	Ctime                   int64        `gorm:"column:ctime" json:"ctime"`
	Mtime                   int64        `gorm:"column:mtime" json:"mtime"`
	Status                  int64        `gorm:"column:status" json:"status"`
	WarehouseOutTime        int64        `gorm:"column:warehouse_out_time" json:"warehouse_out_time"`
	Dealer                  int64        `gorm:"column:dealer" json:"dealer"`
	Manufacturer            int64        `gorm:"column:manufacturer" json:"manufacturer"`
	Manufacturers           Manufacturer `gorm:"ForeignKey:ID;AssociationForeignKey:Manufacturer" json:"Manufacturer"`
	Dealers                 Dealer       `gorm:"ForeignKey:ID;AssociationForeignKey:Dealer" json:"Dealer"`
	Type                    int64        `gorm:"column:type" json:"type"`
	IsSys                   int64        `gorm:"column:is_sys" json:"is_sys"`
}

func (WarehouseOut) TableName() string {
	return "xt_warehouse_out"
}

type WarehouseOutInfo struct {
	ID                      int64        `gorm:"column:id" json:"id"`
	WarehouseOutId          int64        `gorm:"column:warehouse_out_id" json:"warehouse_out_id"`
	WarehouseInfotId        int64        `gorm:"column:warehouse_info_id" json:"warehouse_info_id"`
	GoodId                  int64        `gorm:"column:good_id" json:"good_id"`
	GoodTypeId              int64        `gorm:"column:good_type_id" json:"good_type_id"`
	WarehousingOutTarget    int64        `gorm:"column:warehousing_out_target" json:"warehousing_out_target"`
	Count                   int64        `gorm:"column:count" json:"count"`
	Price                   float64      `gorm:"column:price" json:"price"`
	TotalPrice              float64      `gorm:"column:total_price" json:"total_price"`
	ProductDate             int64        `gorm:"column:product_date" json:"product_date"`
	ExpiryDate              int64        `gorm:"column:expiry_date" json:"expiry_date"`
	Mtime                   int64        `gorm:"column:mtime" json:"mtime"`
	Ctime                   int64        `gorm:"column:ctime" json:"ctime"`
	Status                  int64        `gorm:"column:status" json:"status"`
	OrgId                   int64        `gorm:"column:org_id" json:"org_id"`
	Remark                  string       `gorm:"column:remark" json:"remark"`
	IsCancel                int64        `gorm:"column:is_cancel" json:"is_cancel"`
	WarehouseOut            WarehouseOut `ForeignKey:WarehouseOutId json:"WarehouseOut"`
	WarehouseOutOrderNumber string       `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number"`
	GoodInfo                GoodInfo     `gorm:"ForeignKey:ID;AssociationForeignKey:GoodId" `
	Type                    int64        `gorm:"column:type" json:"type"`
	Dealer                  int64        `gorm:"column:dealer" json:"dealer"`
	Manufacturer            int64        `gorm:"column:manufacturer" json:"manufacturer"`
	IsSys                   int64        `gorm:"column:is_sys" json:"is_sys"`
	SysRecordTime           int64        `gorm:"column:sys_record_time" json:"sys_record_time"`
	PatientId               int64        `gorm:"column:patient_id" json:"patient_id"`
	Number                  string       `gorm:"column:number" json:"number" form:"number"`
	LicenseNumber           string       `gorm:"column:license_number" json:"license_number" form:"license_number"`
	ConsumableType          int64        `gorm:"column:consumable_type" json:"consumable_type" form:"consumable_type"`
}

func (WarehouseOutInfo) TableName() string {
	return "xt_warehouse_out_info"
}

type SalesReturn struct {
	ID           int64  `gorm:"column:id" json:"id"`
	OrderNumber  string `gorm:"column:order_number" json:"order_number"`
	OperaTime    int64  `gorm:"column:opera_time" json:"opera_time"`
	Total        int64  `gorm:"column:total" json:"total"`
	Creater      int64  `gorm:"column:creater" json:"creater"`
	Ctime        int64  `gorm:"column:ctime" json:"ctime"`
	Mtime        int64  `gorm:"column:mtime" json:"mtime"`
	Status       int64  `gorm:"column:status" json:"status"`
	OrgId        int64  `gorm:"column:org_id" json:"org_id"`
	ReturnTime   int64  `gorm:"column:return_time" json:"return_time"`
	Manufacturer int64  `gorm:"column:manufacturer" json:"manufacturer"`
	Dealer       int64  `gorm:"column:dealer" json:"dealer"`
	Type         int64  `gorm:"column:type" json:"type"`
}

func (SalesReturn) TableName() string {
	return "xt_sales_return"
}

type SalesReturnInfo struct {
	ID            int64       `gorm:"column:id" json:"id"`
	GoodId        int64       `gorm:"column:good_id" json:"good_id"`
	SalesReturnId int64       `gorm:"column:sales_return_id" json:"sales_return_id"`
	GoodTypeId    int64       `gorm:"column:good_type_id" json:"good_type_id"`
	Count         int64       `gorm:"column:count" json:"count"`
	Price         float64     `gorm:"column:price" json:"price"`
	Total         float64     `gorm:"column:total" json:"total"`
	ProductDate   int64       `gorm:"column:product_date" json:"product_date"`
	ExpiryDate    int64       `gorm:"column:expiry_date" json:"expiry_date"`
	Ctime         int64       `gorm:"column:ctime" json:"ctime"`
	Mtime         int64       `gorm:"column:mtime" json:"mtime"`
	Status        int64       `gorm:"column:status" json:"status"`
	OrgId         int64       `gorm:"column:org_id" json:"org_id"`
	OrderNumber   string      `gorm:"column:order_number" json:"order_number"`
	Type          int64       `gorm:"column:type" json:"type"`
	SalesReturn   SalesReturn `ForeignKey:SalesReturnId json:"SalesReturn"`
	Dealer        int64       `gorm:"column:dealer" json:"dealer"`
	Manufacturer  int64       `gorm:"column:manufacturer" json:"manufacturer"`
	GoodInfo      GoodInfo    `gorm:"ForeignKey:ID;AssociationForeignKey:GoodId" `
}

func (SalesReturnInfo) TableName() string {
	return "xt_sales_return_info"
}

type VmCancelStockInfo struct {
	GoodId int64 `gorm:"column:good_id" json:"good_id"`
	Count  int64 `gorm:"column:count" json:"count"`
	OrgId  int64 `gorm:"column:org_id" json:"org_id"`
}

type CancelStock struct {
	ID                int64                `gorm:"column:id" json:"id"`
	OrderNumber       string               `gorm:"column:order_number" json:"order_number"`
	OperaTime         int64                `gorm:"column:opera_time" json:"opera_time"`
	Total             int64                `gorm:"column:total" json:"total"`
	Creater           int64                `gorm:"column:creater" json:"creater"`
	Ctime             int64                `gorm:"column:ctime" json:"ctime"`
	Mtime             int64                `gorm:"column:mtime" json:"mtime"`
	Status            int64                `gorm:"column:status" json:"status"`
	OrgId             int64                `gorm:"column:org_id" json:"org_id"`
	ReturnTime        int64                `gorm:"column:return_time" json:"return_time"`
	Dealer            int64                `gorm:"column:dealer" json:"dealer"`
	Manufacturer      int64                `gorm:"column:manufacturer" json:"manufacturer"`
	Type              int64                `gorm:"column:type" json:"type"`
	XtCancelStockInfo []*XtCancelStockInfo `gorm:"ForeignKey:CancelStockId;AssociationForeignKey:ID" json:"XtCancelStockInfo"`
}

func (CancelStock) TableName() string {
	return "xt_cancel_stock"
}

type WarehousingGoodInfo struct {
	ID                int64        `gorm:"column:id" json:"id"`
	GoodCode          string       `gorm:"column:good_code" json:"good_code"`
	SpecificationName string       `gorm:"column:specification_name" json:"specification_name"`
	GoodTypeId        int64        `gorm:"column:good_type_id" json:"good_type_id"`
	GoodUnit          int64        `gorm:"column:good_unit" json:"good_unit"`
	Manufacturer      int64        `gorm:"column:manufacturer" json:"manufacturer"`
	Dealer            int64        `gorm:"column:dealer" json:"dealer"`
	Status            int64        `gorm:"column:status" json:"status"`
	GoodsType         GoodsType    `gorm:"ForeignKey:ID;AssociationForeignKey:GoodTypeId" json:"type"`
	Manufacturers     Manufacturer `gorm:"ForeignKey:Manufacturer;AssociationForeignKey:ID" json:"manufacturers"`
	Dealers           Dealer       `gorm:"ForeignKey:Dealer;AssociationForeignKey:ID" json:"dealers"`
	BuyPrice          float64      `gorm:"column:buy_price" json:"buy_price"`
	Total             float64      `gorm:"column:total" json:"total" form:"total"`
}

func (WarehousingGoodInfo) TableName() string {
	return "xt_good_information"
}

type WarehousingInfoConfig struct {
	ID                  int64               `gorm:"column:id" json:"id"`
	WarehousingId       int64               `gorm:"column:warehousing_id" json:"warehousing_id"`
	GoodId              int64               `gorm:"column:good_id" json:"good_id"`
	WarehousingGoodInfo WarehousingGoodInfo `gorm:"ForeignKey:GoodId;AssociationForeignKey:ID" json:"info"`
}

func (WarehousingInfoConfig) TableName() string {
	return "xt_warehouse_info"
}

type WarehousingOutInfoConfig struct {
	ID                  int64               `gorm:"column:id" json:"id"`
	WarehouseOutId      int64               `gorm:"column:warehouse_out_id" json:"warehouse_out_id"`
	GoodId              int64               `gorm:"column:good_id" json:"good_id"`
	WarehousingGoodInfo WarehousingGoodInfo `gorm:"ForeignKey:GoodId;AssociationForeignKey:ID" json:"info"`
}

func (WarehousingOutInfoConfig) TableName() string {
	return "xt_warehouse_out_info"
}

type AutomaticReduceDetail struct {
	ID                      int64               `gorm:"column:id" json:"id"`
	WarehouseOutId          int64               `gorm:"column:warehouse_out_id" json:"warehouse_out_id"`
	WarehouseOutOrderNumber string              `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number"`
	PatientId               int64               `gorm:"column:patient_id" json:"patient_id"`
	Ctime                   int64               `gorm:"column:ctime" json:"ctime"`
	Mtime                   int64               `gorm:"column:mtime" json:"mtime"`
	Status                  int64               `gorm:"column:status" json:"status"`
	RecordTime              int64               `gorm:"column:record_time" json:"record_time"`
	OrgId                   int64               `gorm:"column:org_id" json:"org_id"`
	GoodId                  int64               `gorm:"column:good_id" json:"good_id"`
	GoodTypeId              int64               `gorm:"column:good_type_id" json:"good_type_id"`
	GoodInfo                GoodInfo            `gorm:"ForeignKey:GoodId;AssociationForeignKey:ID" json:"info"`
	GoodsType               GoodsType           `gorm:"ForeignKey:GoodTypeId;AssociationForeignKey:ID" json:"type"`
	Patients                Patients            `gorm:"ForeignKey:PatientId;AssociationForeignKey:ID" json:"user"`
	Count                   int64               `gorm:"column:count" json:"count"`
	Type                    int64               `gorm:"column:type" json:"type"`
	WarehouseOutInfo        []*WarehouseOutInfo `gorm:"ForeignKey:PatientId;AssociationForeignKey:PatientId" json:"warehouseOutInfo"`
}

func (AutomaticReduceDetail) TableName() string {
	return "xt_automatic_reduce_detail"
}

type VmWarehouseOutInfo struct {
	GoodId int64   `gorm:"column:good_id" json:"good_id"`
	Count  int64   `gorm:"column:count" json:"count"`
	Remark string  `gorm:"column:remark" json:"remark"`
	Price  float64 `gorm:"column:price" json:"price"`
	OrgId  int64   `gorm:"column:org_id" json:"org_id"`
}

type VmWarehouseInfo struct {
	GoodId     int64 `gorm:"column:good_id" json:"good_id"`
	Count      int64 `gorm:"column:count" json:"count"`
	OrgId      int64 `gorm:"column:org_id" json:"org_id"`
	StockCount int64 `gorm:"column:stock_count" json:"stock_count"`
}

type WarehouseOutInfoOne struct {
	ID                      int64   `gorm:"column:id" json:"id"`
	WarehouseOutId          int64   `gorm:"column:warehouse_out_id" json:"warehouse_out_id"`
	WarehouseInfotId        int64   `gorm:"column:warehouse_info_id" json:"warehouse_info_id"`
	GoodId                  int64   `gorm:"column:good_id" json:"good_id"`
	GoodTypeId              int64   `gorm:"column:good_type_id" json:"good_type_id"`
	WarehousingOutTarget    int64   `gorm:"column:warehousing_out_target" json:"warehousing_out_target"`
	Count                   int64   `gorm:"column:count" json:"count"`
	Price                   float64 `gorm:"column:price" json:"price"`
	TotalPrice              float64 `gorm:"column:total_price" json:"total_price"`
	ProductDate             int64   `gorm:"column:product_date" json:"product_date"`
	ExpiryDate              int64   `gorm:"column:expiry_date" json:"expiry_date"`
	Mtime                   int64   `gorm:"column:mtime" json:"mtime"`
	Ctime                   int64   `gorm:"column:ctime" json:"ctime"`
	Status                  int64   `gorm:"column:status" json:"status"`
	OrgId                   int64   `gorm:"column:org_id" json:"org_id"`
	Remark                  string  `gorm:"column:remark" json:"remark"`
	IsCancel                int64   `gorm:"column:is_cancel" json:"is_cancel"`
	WarehouseOutOrderNumber string  `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number"`
	Type                    int64   `gorm:"column:type" json:"type"`
	Dealer                  int64   `gorm:"column:dealer" json:"dealer"`
	Manufacturer            int64   `gorm:"column:manufacturer" json:"manufacturer"`
	IsSys                   int64   `gorm:"column:is_sys" json:"is_sys"`
	SysRecordTime           int64   `gorm:"column:sys_record_time" json:"sys_record_time"`
	PatientId               int64   `gorm:"column:patient_id" json:"patient_id"`
	GoodName                string  `gorm:"column:good_name" json:"good_name" form:"good_name"`
	SpecificationName       string  `gorm:"column:specification_name" json:"specification_name" form:"specification_name"`
	MinNumber               int64   `gorm:"column:min_number" json:"min_number" form:"min_number"`
	PackingPrice            float64 `gorm:"column:packing_price" json:"packing_price" form:"packing_price"`
	MinUnit                 string  `gorm:"column:min_unit" json:"min_unit" form:"min_unit"`
	Number                  string  `gorm:"column:number" json:"number" form:"number"`
	PackingUnit             string  `gorm:"column:packing_unit" json:"packing_unit" form:"packing_unit"`
	LicenseNumber           string  `gorm:"column:license_number" json:"license_number" form:"license_number"`
}

type WarehouseOutInfoTwo struct {
	ID                      int64                `gorm:"column:id" json:"id"`
	WarehouseOutId          int64                `gorm:"column:warehouse_out_id" json:"warehouse_out_id"`
	WarehouseInfotId        int64                `gorm:"column:warehouse_info_id" json:"warehouse_info_id"`
	GoodId                  int64                `gorm:"column:good_id" json:"good_id"`
	GoodTypeId              int64                `gorm:"column:good_type_id" json:"good_type_id"`
	WarehousingOutTarget    int64                `gorm:"column:warehousing_out_target" json:"warehousing_out_target"`
	Count                   int64                `gorm:"column:count" json:"count"`
	Price                   float64              `gorm:"column:price" json:"price"`
	TotalPrice              float64              `gorm:"column:total_price" json:"total_price"`
	ProductDate             int64                `gorm:"column:product_date" json:"product_date"`
	ExpiryDate              int64                `gorm:"column:expiry_date" json:"expiry_date"`
	Mtime                   int64                `gorm:"column:mtime" json:"mtime"`
	Ctime                   int64                `gorm:"column:ctime" json:"ctime"`
	Status                  int64                `gorm:"column:status" json:"status"`
	OrgId                   int64                `gorm:"column:org_id" json:"org_id"`
	Remark                  string               `gorm:"column:remark" json:"remark"`
	IsCancel                int64                `gorm:"column:is_cancel" json:"is_cancel"`
	WarehouseOutOrderNumber string               `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number"`
	Type                    int64                `gorm:"column:type" json:"type"`
	Dealer                  int64                `gorm:"column:dealer" json:"dealer"`
	Manufacturer            int64                `gorm:"column:manufacturer" json:"manufacturer"`
	IsSys                   int64                `gorm:"column:is_sys" json:"is_sys"`
	SysRecordTime           int64                `gorm:"column:sys_record_time" json:"sys_record_time"`
	PatientId               int64                `gorm:"column:patient_id" json:"patient_id"`
	GoodName                string               `gorm:"column:good_name" json:"good_name" form:"good_name"`
	SpecificationName       string               `gorm:"column:specification_name" json:"specification_name" form:"specification_name"`
	MinNumber               int64                `gorm:"column:min_number" json:"min_number" form:"min_number"`
	PackingPrice            float64              `gorm:"column:packing_price" json:"packing_price" form:"packing_price"`
	MinUnit                 string               `gorm:"column:min_unit" json:"min_unit" form:"min_unit"`
	Number                  string               `gorm:"column:number" json:"number" form:"number"`
	PackingUnit             string               `gorm:"column:packing_unit" json:"packing_unit" form:"packing_unit"`
	StWarehousingInfo       []*StWarehousingInfo `gorm:"ForeignKey:good_id;AssociationForeignKey:GoodId" json:"xt_warehouse_info"`
}

type WarehouseOutInfoSix struct {
	ID                      int64        `gorm:"column:id" json:"id"`
	WarehouseOutId          int64        `gorm:"column:warehouse_out_id" json:"warehouse_out_id"`
	WarehouseInfotId        int64        `gorm:"column:warehouse_info_id" json:"warehouse_info_id"`
	GoodId                  int64        `gorm:"column:good_id" json:"good_id"`
	GoodTypeId              int64        `gorm:"column:good_type_id" json:"good_type_id"`
	WarehousingOutTarget    int64        `gorm:"column:warehousing_out_target" json:"warehousing_out_target"`
	Count                   int64        `gorm:"column:count" json:"count"`
	Price                   float64      `gorm:"column:price" json:"price"`
	TotalPrice              float64      `gorm:"column:total_price" json:"total_price"`
	ProductDate             int64        `gorm:"column:product_date" json:"product_date"`
	ExpiryDate              int64        `gorm:"column:expiry_date" json:"expiry_date"`
	Mtime                   int64        `gorm:"column:mtime" json:"mtime"`
	Ctime                   int64        `gorm:"column:ctime" json:"ctime"`
	Status                  int64        `gorm:"column:status" json:"status"`
	OrgId                   int64        `gorm:"column:org_id" json:"org_id"`
	Remark                  string       `gorm:"column:remark" json:"remark"`
	IsCancel                int64        `gorm:"column:is_cancel" json:"is_cancel"`
	WarehouseOut            WarehouseOut `ForeignKey:WarehouseOutId json:"WarehouseOut"`
	WarehouseOutOrderNumber string       `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number"`
	Type                    int64        `gorm:"column:type" json:"type"`
	Dealer                  int64        `gorm:"column:dealer" json:"dealer"`
	Manufacturer            int64        `gorm:"column:manufacturer" json:"manufacturer"`
	IsSys                   int64        `gorm:"column:is_sys" json:"is_sys"`
	SysRecordTime           int64        `gorm:"column:sys_record_time" json:"sys_record_time"`
	PatientId               int64        `gorm:"column:patient_id" json:"patient_id"`
	Number                  string       `gorm:"column:number" json:"number" form:"number"`
	LicenseNumber           string       `gorm:"column:license_number" json:"license_number" form:"license_number"`
	ConsumableType          int64        `gorm:"column:consumable_type" json:"consumable_type" form:"consumable_type"`
	GoodInfo                GoodInfo     `gorm:"ForeignKey:GoodId;AssociationForeignKey:ID" json:"info"`
}

func (WarehouseOutInfoSix) TableName() string {
	return "xt_warehouse_out_info"
}

type VmStockFlow struct {
	ID                      int64   `gorm:"column:id" json:"id" form:"id"`
	WarehousingId           int64   `gorm:"column:warehousing_id" json:"warehousing_id" form:"warehousing_id"`
	GoodId                  int64   `gorm:"column:good_id" json:"good_id" form:"good_id"`
	Number                  string  `gorm:"column:number" json:"number" form:"number"`
	LicenseNumber           string  `gorm:"column:license_number" json:"license_number" form:"license_number"`
	Count                   int64   `gorm:"column:count" json:"count" form:"count"`
	UserOrgId               int64   `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId               int64   `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	SystemTime              int64   `gorm:"column:system_time" json:"system_time" form:"system_time"`
	ConsumableType          int64   `gorm:"column:consumable_type" json:"consumable_type" form:"consumable_type"`
	IsSys                   int64   `gorm:"column:is_sys" json:"is_sys" form:"is_sys"`
	WarehousingOrder        string  `gorm:"column:warehousing_order" json:"warehousing_order" form:"warehousing_order"`
	WarehouseOutId          int64   `gorm:"column:warehouse_out_id" json:"warehouse_out_id" form:"warehouse_out_id"`
	WarehouseOutOrderNumber string  `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number" form:"warehouse_out_order_number"`
	IsEdit                  int64   `gorm:"column:is_edit" json:"is_edit" form:"is_edit"`
	CancelStockId           int64   `gorm:"column:cancel_stock_id" json:"cancel_stock_id" form:"cancel_stock_id"`
	CancelOrderNumber       string  `gorm:"column:cancel_order_number" json:"cancel_order_number" form:"cancel_order_number"`
	Manufacturer            int64   `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	Dealer                  int64   `gorm:"column:dealer" json:"dealer" form:"dealer"`
	Creator                 int64   `gorm:"column:creator" json:"creator" form:"creator"`
	UpdateCreator           int64   `gorm:"column:update_creator" json:"update_creator" form:"update_creator"`
	Status                  int64   `gorm:"column:status" json:"status" form:"status"`
	Ctime                   int64   `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                   int64   `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Price                   float64 `gorm:"column:price" json:"price" form:"price"`
	WarehousingDetailId     int64   `gorm:"column:warehousing_detail_id" json:"warehousing_detail_id" form:"warehousing_detail_id"`
	WarehouseOutDetailId    int64   `gorm:"column:warehouse_out_detail_id" json:"warehouse_out_detail_id" form:"warehouse_out_detail_id"`
	CancelOutDetailId       int64   `gorm:"column:cancel_out_detail_id" json:"cancel_out_detail_id" form:"cancel_out_detail_id"`
	ProductDate             int64   `gorm:"column:product_date" json:"product_date" form:"product_date"`
	ExpireDate              int64   `gorm:"column:expire_date" json:"expire_date" form:"expire_date"`
	ReturnCount             int64   `gorm:"column:return_count" json:"return_count" form:"return_count"`
}

func (VmStockFlow) TableName() string {
	return "xt_stock_flow"
}

type CancelStockInfo struct {
	ID              int64       `gorm:"column:id" json:"id"`
	GoodId          int64       `gorm:"column:good_id" json:"good_id"`
	CancelStockId   int64       `gorm:"column:cancel_stock_id" json:"cancel_stock_id"`
	GoodTypeId      int64       `gorm:"column:good_type_id" json:"good_type_id"`
	Count           int64       `gorm:"column:count" json:"count"`
	Price           float64     `gorm:"column:price" json:"price"`
	Total           float64     `gorm:"column:total" json:"total"`
	ProductDate     int64       `gorm:"column:product_date" json:"product_date"`
	ExpiryDate      int64       `gorm:"column:expiry_date" json:"expiry_date"`
	Ctime           int64       `gorm:"column:ctime" json:"ctime"`
	Mtime           int64       `gorm:"column:mtime" json:"mtime"`
	Status          int64       `gorm:"column:status" json:"status"`
	OrgId           int64       `gorm:"column:org_id" json:"org_id"`
	OrderNumber     string      `gorm:"column:order_number" json:"order_number"`
	Type            int64       `gorm:"column:type" json:"type"`
	CancelStock     CancelStock `ForeignKey:CancelStockId json:"CancelStock"`
	Dealer          string      `gorm:"column:dealer" json:"dealer"`
	Manufacturer    string      `gorm:"column:manufacturer" json:"manufacturer"`
	Number          string      `gorm:"column:number" json:"number" form:"number"`
	RegisterAccount string      `gorm:"column:register_account" json:"register_account" form:"register_account"`
	Remark          string      `gorm:"column:remark" json:"remark" form:"remark"`
	WarehouseInfoId int64       `gorm:"column:warehouse_info_id" json:"warehouse_info_id" form:"warehouse_info_id"`
	GoodInfo        GoodInfo    `gorm:"ForeignKey:ID;AssociationForeignKey:GoodId" `
}

func (CancelStockInfo) TableName() string {
	return "xt_cancel_stock_info"
}

type VmBaseDrug struct {
	ID                          int64                     `gorm:"column:id" json:"id" form:"id"`
	DrugName                    string                    `gorm:"column:drug_name" json:"drug_name" form:"drug_name"`
	Pinyin                      string                    `gorm:"column:pinyin" json:"pinyin" form:"pinyin"`
	Wubi                        string                    `gorm:"column:wubi" json:"wubi" form:"wubi"`
	DrugAlias                   string                    `gorm:"column:drug_alias" json:"drug_alias" form:"drug_alias"`
	DrugAliasPinyin             string                    `gorm:"column:drug_alias_pinyin" json:"drug_alias_pinyin" form:"drug_alias_pinyin"`
	DrugAliasWubi               string                    `gorm:"column:drug_alias_wubi" json:"drug_alias_wubi" form:"drug_alias_wubi"`
	DrugCategory                int64                     `gorm:"column:drug_category" json:"drug_category" form:"drug_category"`
	DrugSpec                    string                    `gorm:"column:drug_spec" json:"drug_spec" form:"drug_spec"`
	DrugType                    int64                     `gorm:"column:drug_type" json:"drug_type" form:"drug_type"`
	DrugStockLimit              string                    `gorm:"column:drug_stock_limit" json:"drug_stock_limit" form:"drug_stock_limit"`
	DrugOriginPlace             string                    `gorm:"column:drug_origin_place" json:"drug_origin_place" form:"drug_origin_place"`
	DrugDosageForm              int64                     `gorm:"column:drug_dosage_form" json:"drug_dosage_form" form:"drug_dosage_form"`
	MedicalInsuranceLevel       int64                     `gorm:"column:medical_insurance_level" json:"medical_insurance_level" form:"medical_insurance_level"`
	MaxUnit                     string                    `gorm:"column:max_unit" json:"max_unit" form:"max_unit"`
	MinNumber                   int64                     `gorm:"column:min_number" json:"min_number" form:"min_number"`
	MinUnit                     string                    `gorm:"column:min_unit" json:"min_unit" form:"min_unit"`
	Dose                        float64                   `gorm:"column:dose" json:"dose" form:"dose"`
	DoseUnit                    string                    `gorm:"column:dose_unit" json:"dose_unit" form:"dose_unit"`
	UnitMatrixing               string                    `gorm:"column:unit_matrixing" json:"unit_matrixing" form:"unit_matrixing"`
	RetailPrice                 float64                   `gorm:"column:retail_price" json:"retail_price" form:"retail_price"`
	MinPrice                    float64                   `gorm:"column:min_price" json:"min_price" form:"min_price"`
	LastPrice                   float64                   `gorm:"column:last_price" json:"last_price" form:"last_price"`
	DrugControl                 int64                     `gorm:"column:drug_control" json:"drug_control" form:"drug_control"`
	Number                      string                    `gorm:"column:number" json:"number" form:"number"`
	DrugClassify                string                    `gorm:"column:drug_classify" json:"drug_classify" form:"drug_classify"`
	DrugDose                    float64                   `gorm:"column:drug_dose" json:"drug_dose" form:"drug_dose"`
	DrugDoseUnit                int64                     `gorm:"column:drug_dose_unit" json:"drug_dose_unit" form:"drug_dose_unit"`
	MedicalInsuranceNumber      string                    `gorm:"column:medical_insurance_number" json:"medical_insurance_number" form:"medical_insurance_number"`
	Manufacturer                int64                     `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	PharmacologyCategory        int64                     `gorm:"column:pharmacology_category" json:"pharmacology_category" form:"pharmacology_category"`
	StatisticsCategory          int64                     `gorm:"column:statistics_category" json:"statistics_category" form:"statistics_category"`
	Code                        string                    `gorm:"column:code" json:"code" form:"code"`
	IsSpecialDiseases           int64                     `gorm:"column:is_special_diseases" json:"is_special_diseases" form:"is_special_diseases"`
	IsRecord                    int64                     `gorm:"column:is_record" json:"is_record" form:"is_record"`
	Agent                       string                    `gorm:"column:agent" json:"agent" form:"agent"`
	DrugStatus                  string                    `gorm:"column:drug_status" json:"drug_status" form:"drug_status"`
	LimitRemark                 string                    `gorm:"column:limit_remark" json:"limit_remark" form:"limit_remark"`
	DeliveryWay                 string                    `gorm:"column:delivery_way" json:"delivery_way" form:"delivery_way"`
	ExecutionFrequency          string                    `gorm:"column:execution_frequency" json:"execution_frequency" form:"execution_frequency"`
	SingleDose                  float64                   `gorm:"column:single_dose" json:"single_dose" form:"single_dose"`
	PrescribingNumber           float64                   `gorm:"column:prescribing_number" json:"prescribing_number" form:"prescribing_number"`
	Label                       int64                     `gorm:"column:label" json:"label" form:"label"`
	Sort                        int64                     `gorm:"column:sort" json:"sort" form:"sort"`
	IsUseDoctorAdvice           int64                     `gorm:"column:is_use_doctor_advice" json:"is_use_doctor_advice" form:"is_use_doctor_advice"`
	IsDefault                   int64                     `gorm:"column:is_default" json:"is_default" form:"is_default"`
	IsChargePredict             int64                     `gorm:"column:is_charge_predict" json:"is_charge_predict" form:"is_charge_predict"`
	IsStatisticsWork            int64                     `gorm:"column:is_statistics_work" json:"is_statistics_work" form:"is_statistics_work"`
	IsChargeUse                 int64                     `gorm:"column:is_charge_use" json:"is_charge_use" form:"is_charge_use"`
	Status                      int64                     `gorm:"column:status" json:"status" form:"status"`
	Ctime                       int64                     `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                       int64                     `gorm:"column:mtime" json:"mtime" form:"mtime"`
	OrgId                       int64                     `gorm:"column:org_id" json:"org_id" form:"org_id"`
	DrugCode                    string                    `gorm:"column:drug_code" json:"drug_code" form:"drug_code"`
	Dealer                      int64                     `gorm:"column:dealer" json:"dealer" form:"dealer"`
	PrescriptionMark            int64                     `gorm:"column:prescription_mark" json:"prescription_mark" form:"prescription_mark"`
	RecordDate                  int64                     `gorm:"column:record_date" json:"record_date" form:"record_date"`
	DrugRemark                  string                    `gorm:"column:drug_remark" json:"drug_remark" form:"drug_remark"`
	SocialSecurityDirectoryCode string                    `gorm:"column:social_security_directory_code" json:"social_security_directory_code" form:"social_security_directory_code"`
	DoseCode                    string                    `gorm:"column:dose_code" json:"dose_code" form:"dose_code"`
	IsMark                      int64                     `gorm:"column:is_mark" json:"is_mark" form:"is_mark"`
	HospApprFlag                int64                     `gorm:"column:hosp_appr_flag" json:"hosp_appr_flag" form:"hosp_appr_flag"`
	LmtUsedFlag                 int64                     `gorm:"column:lmt_used_flag" json:"lmt_used_flag" form:"lmt_used_flag"`
	DrugDay                     string                    `gorm:"column:drug_day" json:"drug_day" form:"drug_day"`
	Total                       float64                   `gorm:"column:total" json:"total" form:"total"`
	PrescribingNumberUnit       string                    `gorm:"column:prescribing_number_unit" json:"prescribing_number_unit" form:"prescribing_number_unit"`
	DrugWarehouseInfo           []*VsDrugWarehouseInfo    `gorm:"ForeignKey:DrugId;AssociationForeignKey:ID" json:"drug_warehouse_info"`
	DrugCancelStockInfo         []*VsDrugCancelStockInfo  `gorm:"ForeignKey:DrugId;AssociationForeignKey:ID" json:"drug_cancel_stock_info"`
	DrugWarehouseOutInfo        []*VsDrugWarehouseOutInfo `gorm:"ForeignKey:DrugId;AssociationForeignKey:ID" json:"drug_warehouse_out"`
}

func (VmBaseDrug) TableName() string {
	return "xt_base_drug"
}

type VsDrugWarehouseInfo struct {
	ID               int64   `gorm:"column:id" json:"id" form:"id"`
	WarehousingId    int64   `gorm:"column:warehousing_id" json:"warehousing_id" form:"warehousing_id"`
	DrugId           int64   `gorm:"column:drug_id" json:"drug_id" form:"drug_id"`
	Number           string  `gorm:"column:number" json:"number" form:"number"`
	ProductDate      int64   `gorm:"column:product_date" json:"product_date" form:"product_date"`
	ExpiryDate       int64   `gorm:"column:expiry_date" json:"expiry_date" form:"expiry_date"`
	WarehousingCount int64   `gorm:"column:warehousing_count" json:"warehousing_count" form:"warehousing_count"`
	WarehouseingUnit string  `gorm:"column:warehouseing_unit" json:"warehouseing_unit" form:"warehouseing_unit"`
	MaxUnit          string  `gorm:"column:max_unit" json:"max_unit" form:"max_unit"`
	MinUnit          string  `gorm:"column:min_unit" json:"min_unit" form:"min_unit"`
	StockMaxNumber   int64   `gorm:"column:stock_max_number" json:"stock_max_number" form:"stock_max_number"`
	StockMinNumber   int64   `gorm:"column:stock_min_number" json:"stock_min_number" form:"stock_min_number"`
	Price            float64 `gorm:"column:price" json:"price" form:"price"`
	TotalPrice       float64 `gorm:"column:total_price" json:"total_price" form:"total_price"`
	Dealer           int64   `gorm:"column:dealer" json:"dealer" form:"dealer"`
	Manufacturer     int64   `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	Remark           string  `gorm:"column:remark" json:"remark" form:"remark"`
	Ctime            int64   `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime            int64   `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status           int64   `gorm:"column:status" json:"status" form:"status"`
	OrgId            int64   `gorm:"column:org_id" json:"org_id" form:"org_id"`
	IsReturn         int64   `gorm:"column:is_return" json:"is_return" form:"is_return"`
	WarehousingOrder string  `gorm:"column:warehousing_order" json:"warehousing_order" form:"warehousing_order"`
	Type             int64   `gorm:"column:type" json:"type" form:"type"`
	RetailPrice      float64 `gorm:"column:retail_price" json:"retail_price" form:"retail_price"`
	RetailTotalPrice float64 `gorm:"column:retail_total_price" json:"retail_total_price" form:"retail_total_price"`
	BatchNumber      string  `gorm:"column:batch_number" json:"batch_number" form:"batch_number"`
}

func (VsDrugWarehouseInfo) TableName() string {
	return "xt_drug_warehouse_info"
}

type VsDrugCancelStockInfo struct {
	ID               int64       `gorm:"column:id" json:"id" form:"id"`
	DrugId           int64       `gorm:"column:drug_id" json:"drug_id" form:"drug_id"`
	CancelStockId    int64       `gorm:"column:cancel_stock_id" json:"cancel_stock_id" form:"cancel_stock_id"`
	Count            int64       `gorm:"column:count" json:"count" form:"count"`
	Price            float64     `gorm:"column:price" json:"price" form:"price"`
	Total            float64     `gorm:"column:total" json:"total" form:"total"`
	ProductDate      int64       `gorm:"column:product_date" json:"product_date" form:"product_date"`
	ExpiryDate       int64       `gorm:"column:expiry_date" json:"expiry_date" form:"expiry_date"`
	Ctime            int64       `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime            int64       `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status           int64       `gorm:"column:status" json:"status" form:"status"`
	OrgId            int64       `gorm:"column:org_id" json:"org_id" form:"org_id"`
	OrderNumber      string      `gorm:"column:order_number" json:"order_number" form:"order_number"`
	Type             int64       `gorm:"column:type" json:"type" form:"type"`
	Dealer           string      `gorm:"column:dealer" json:"dealer" form:"dealer"`
	Manufacturer     string      `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	RetailPrice      float64     `gorm:"column:retail_price" json:"retail_price" form:"retail_price"`
	RetailTotalPrice float64     `gorm:"column:retail_total_price" json:"retail_total_price" form:"retail_total_price"`
	Number           string      `gorm:"column:number" json:"number" form:"number"`
	RegisterAccount  string      `gorm:"column:register_account" json:"register_account" form:"register_account"`
	Remark           string      `gorm:"column:remark" json:"remark" form:"remark"`
	BatchNumber      string      `gorm:"column:batch_number" json:"batch_number" form:"batch_number"`
	MaxUnit          string      `gorm:"column:max_unit" json:"max_unit" form:"max_unit"`
	BaseDrugLib      BaseDrugLib `gorm:"ForeignKey:DrugId;AssociationForeignKey:ID" `
}

func (VsDrugCancelStockInfo) TableName() string {
	return "xt_drug_cancel_stock_info"
}

type VsDrugWarehouseOutInfo struct {
	ID                      int64   `gorm:"column:id" json:"id" form:"id"`
	WarehouseOutId          int64   `gorm:"column:warehouse_out_id" json:"warehouse_out_id" form:"warehouse_out_id"`
	DrugId                  int64   `gorm:"column:drug_id" json:"drug_id" form:"drug_id"`
	WarehousingOutTarget    int64   `gorm:"column:warehousing_out_target" json:"warehousing_out_target" form:"warehousing_out_target"`
	Count                   int64   `gorm:"column:count" json:"count" form:"count"`
	Price                   float64 `gorm:"column:price" json:"price" form:"price"`
	TotalPrice              float64 `gorm:"column:total_price" json:"total_price" form:"total_price"`
	ProductDate             int64   `gorm:"column:product_date" json:"product_date" form:"product_date"`
	ExpiryDate              int64   `gorm:"column:expiry_date" json:"expiry_date" form:"expiry_date"`
	Mtime                   int64   `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Ctime                   int64   `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Status                  int64   `gorm:"column:status" json:"status" form:"status"`
	OrgId                   int64   `gorm:"column:org_id" json:"org_id" form:"org_id"`
	Remark                  string  `gorm:"column:remark" json:"remark" form:"remark"`
	IsCancel                int64   `gorm:"column:is_cancel" json:"is_cancel" form:"is_cancel"`
	WarehouseOutOrderNumber string  `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number" form:"warehouse_out_order_number"`
	Type                    int64   `gorm:"column:type" json:"type" form:"type"`
	Dealer                  int64   `gorm:"column:dealer" json:"dealer" form:"dealer"`
	Manufacturer            int64   `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	IsSys                   int64   `gorm:"column:is_sys" json:"is_sys" form:"is_sys"`
	SysRecordTime           int64   `gorm:"column:sys_record_time" json:"sys_record_time" form:"sys_record_time"`
	RetailPrice             float64 `gorm:"column:retail_price" json:"retail_price" form:"retail_price"`
	RetailTotalPrice        float64 `gorm:"column:retail_total_price" json:"retail_total_price" form:"retail_total_price"`
	CountUnit               string  `gorm:"column:count_unit" json:"count_unit" form:"count_unit"`
}

func (VsDrugWarehouseOutInfo) TableName() string {
	return "xt_drug_warehouse_out_info"
}

type VmStockFlowOne struct {
	ID                      int64   `gorm:"column:id" json:"id" form:"id"`
	WarehousingId           int64   `gorm:"column:warehousing_id" json:"warehousing_id" form:"warehousing_id"`
	GoodId                  int64   `gorm:"column:good_id" json:"good_id" form:"good_id"`
	Number                  string  `gorm:"column:number" json:"number" form:"number"`
	Count                   int64   `gorm:"column:count" json:"count" form:"count"`
	PatientId               int64   `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	SystemTime              int64   `gorm:"column:system_time" json:"system_time" form:"system_time"`
	IsSys                   int64   `gorm:"column:is_sys" json:"is_sys" form:"is_sys"`
	WarehousingOrder        string  `gorm:"column:warehousing_order" json:"warehousing_order" form:"warehousing_order"`
	WarehouseOutId          int64   `gorm:"column:warehouse_out_id" json:"warehouse_out_id" form:"warehouse_out_id"`
	WarehouseOutOrderNumber string  `gorm:"column:warehouse_out_order_number" json:"warehouse_out_order_number" form:"warehouse_out_order_number"`
	Price                   float64 `gorm:"column:price" json:"price" form:"price"`
	ProductDate             int64   `gorm:"column:product_date" json:"product_date" form:"product_date"`
	ExpireDate              int64   `gorm:"column:expire_date" json:"expire_date" form:"expire_date"`
	PackingUnit             string  `gorm:"column:packing_unit" json:"packing_unit" form:"packing_unit"`
	Ctime                   int64   `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Name                    string  `gorm:"column:name" json:"name" form:"name"`
}
